.. _image_muon:

====================
Muon image analysis
====================

Algorithms for detecting and characterizing muon images

.. automodapi:: ctapipe.image.muon

.. automodapi:: ctapipe.image.muon.intensity_fitter

.. automodapi:: ctapipe.image.muon.ring_fitter
